@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -35,11 +35,11 @@
 		if(check_rights($_GET['action'], $_SESSION['ID']))
 			{
 			// load config, settings, template and language files
-			require ("../config.inc.php");
-			require ("../load_settings.inc.php");
+			require ("../includes/config.inc.php");
+			require ("../includes/load_settings.inc.php");
 			require("../language/".$settings['language_path']."/lang_admin.php");
 			require ("load_template_admin.inc.php");
-			require ("../functions.inc.php");
+			require ("../includes/functions.inc.php");
 
 			// connect to database
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(edit_user.inc.php) Error, line 45: ".mysql_error());
@@ -91,6 +91,7 @@
 							$_POST['r_deactivate'] = cleanstr($_POST['r_deactivate']);
 							$_POST['r_delete'] = cleanstr($_POST['r_delete']);
 							$_POST['r_edit'] = cleanstr($_POST['r_edit']);
+							$_POST['r_spam'] = cleanstr($_POST['r_spam']);
 							$_POST['old_password'] = cleanstr($_POST['old_password']);
 							$_POST['new_password_1'] = cleanstr($_POST['new_password_1']);
 							$_POST['new_password_2'] = cleanstr($_POST['new_password_2']);
@@ -164,10 +165,11 @@
 											`r_activate` = '".$_POST['r_activate']."',
 											`r_deactivate` = '".$_POST['r_deactivate']."',
 											`r_delete` = '".$_POST['r_delete']."',
-											`r_edit` = '".$_POST['r_edit']."'
+											`r_edit` = '".$_POST['r_edit']."',
+											`r_spam` = '".$_POST['r_spam']."'
 											WHERE ID=".secure_value($_GET['id'])." LIMIT 1";
 
-									if ( @mysql_query($sql, $link) or die ("(edit_user.inc.php) Error, Line 170: ".mysql_error()) )
+									if ( @mysql_query($sql, $link) or die ("(edit_user.inc.php) Error, Line 171: ".mysql_error()) )
 										{
 										$saved_settings_successfull = 1;
 										}
@@ -212,6 +214,7 @@
 						$r_deactivate = $user['r_deactivate'];
 						$r_delete = $user['r_delete'];
 						$r_edit = $user['r_edit'];
+						$r_spam = $user['r_spam'];
 
 						if($_SESSION['ID'] == $userID)
 							{
@@ -231,6 +234,7 @@
 						if ($r_deactivate == 0) { $selected_r_deactivate_0 = " selected"; $selected_r_deactivate_1 = NULL; } else { $selected_r_deactivate_0 = NULL; $selected_r_deactivate_1 = " selected"; }
 						if ($r_delete == 0) { $selected_r_delete_0 = " selected"; $selected_r_delete_1 = NULL; } else { $selected_r_delete_0 = NULL; $selected_r_delete_1 = " selected"; }
 						if ($r_edit == 0) { $selected_r_edit_0 = " selected"; $selected_r_edit_1 = NULL; } else { $selected_r_edit_0 = NULL; $selected_r_edit_1 = " selected"; }
+						if ($r_spam == 0) { $selected_r_spam_0 = " selected"; $selected_r_spam_1 = NULL; } else { $selected_r_spam_0 = NULL; $selected_r_spam_1 = " selected"; }
 
 						$page_edit_user_single = preg_replace("/\{TEMPLATE_ERRORMESSAGE\}/", $content_errormessage, $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{ERRORMESSAGE\}/", $errormessage, $page_edit_user_single);
@@ -248,6 +252,7 @@
 						$page_edit_user_single = preg_replace("/\{LANG_R_DEACTIVATE\}/", $lang['r_deactivate'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_R_DELETE\}/", $lang['r_delete'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_R_EDIT\}/", $lang['r_edit'], $page_edit_user_single);
+						$page_edit_user_single = preg_replace("/\{LANG_R_SPAM\}/", $lang['r_spam'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_EDIT_USER_CAPTION_PASSWORD\}/", $lang['edit_user_caption_password'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_NEW_PASSWORD_1\}/", $lang['new_password_1'], $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{LANG_NEW_PASSWORD_2\}/", $lang['new_password_2'], $page_edit_user_single);
@@ -276,6 +281,8 @@
 						$page_edit_user_single = preg_replace("/\{SELECTED_R_DELETE_1\}/", $selected_r_delete_1, $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{SELECTED_R_EDIT_0\}/", $selected_r_edit_0, $page_edit_user_single);
 						$page_edit_user_single = preg_replace("/\{SELECTED_R_EDIT_1\}/", $selected_r_edit_1, $page_edit_user_single);
+						$page_edit_user_single = preg_replace("/\{SELECTED_R_SPAM_0\}/", $selected_r_spam_0, $page_edit_user_single);
+						$page_edit_user_single = preg_replace("/\{SELECTED_R_SPAM_1\}/", $selected_r_spam_1, $page_edit_user_single);
 
 						$page_edit_user_single = preg_replace("/\{FORM_ACTION\}/", "admin.php?action=editusers&amp;mode=edit&amp;id=".$userID.$sid, $page_edit_user_single);
 
@@ -301,6 +308,7 @@
 					$_POST['r_deactivate'] = cleanstr($_POST['r_deactivate']);
 					$_POST['r_delete'] = cleanstr($_POST['r_delete']);
 					$_POST['r_edit'] = cleanstr($_POST['r_edit']);
+					$_POST['r_spam'] = cleanstr($_POST['r_spam']);
 					$_POST['old_password'] = cleanstr($_POST['old_password']);
 					$_POST['new_password_1'] = cleanstr($_POST['new_password_1']);
 					$_POST['new_password_2'] = cleanstr($_POST['new_password_2']);
@@ -349,6 +357,7 @@
 										`r_deactivate`,
 										`r_delete`,
 										`r_edit`,
+										`r_spam`,
 										`logged_out`
 									) VALUES (
 										'".$_POST['name']."',
@@ -361,6 +370,7 @@
 										'".$_POST['r_deactivate']."',
 										'".$_POST['r_delete']."',
 										'".$_POST['r_edit']."',
+										'".$_POST['r_spam']."',
 										'".$_POST['logged_out']."'
 									);";
 
@@ -415,6 +425,7 @@
 					$page_edit_user_adduser = preg_replace("/\{LANG_R_DEACTIVATE\}/", $lang['r_deactivate'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_R_DELETE\}/", $lang['r_delete'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_R_EDIT\}/", $lang['r_edit'], $page_edit_user_adduser);
+					$page_edit_user_adduser = preg_replace("/\{LANG_R_SPAM\}/", $lang['r_spam'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_EDIT_USER_CAPTION_PASSWORD\}/", $lang['edit_user_caption_password'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_NEW_PASSWORD_1\}/", $lang['new_password_1'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{LANG_NEW_PASSWORD_2\}/", $lang['new_password_2'], $page_edit_user_adduser);
@@ -435,6 +446,7 @@
 					if ($_POST['r_deactivate'] == 0) { $selected_r_deactivate_0 = " selected"; $selected_r_deactivate_1 = NULL; } else { $selected_r_deactivate_0 = NULL; $selected_r_deactivate_1 = " selected"; }
 					if ($_POST['r_delete'] == 0) { $selected_r_delete_0 = " selected"; $selected_r_delete_1 = NULL; } else { $selected_r_delete_0 = NULL; $selected_r_delete_1 = " selected"; }
 					if ($_POST['r_edit'] == 0) { $selected_r_edit_0 = " selected"; $selected_r_edit_1 = NULL; } else { $selected_r_edit_0 = NULL; $selected_r_edit_1 = " selected"; }
+					if ($_POST['r_spam'] == 0) { $selected_r_spam_0 = " selected"; $selected_r_spam_1 = NULL; } else { $selected_r_spam_0 = NULL; $selected_r_spam_1 = " selected"; }
 
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_NAME\}/", $_POST['name'], $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_EMAIL\}/", $_POST['email'], $page_edit_user_adduser);
@@ -452,6 +464,8 @@
 					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_DELETE_1\}/", $selected_r_delete_1, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_EDIT_0\}/", $selected_r_edit_0, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_EDIT_1\}/", $selected_r_edit_1, $page_edit_user_adduser);
+					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_SPAM_0\}/", $selected_r_spam_0, $page_edit_user_adduser);
+					$page_edit_user_adduser = preg_replace("/\{SELECTED_R_SPAM_1\}/", $selected_r_spam_1, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_NEW_PASSWORD_1\}/", $save_pw, $page_edit_user_adduser);
 					$page_edit_user_adduser = preg_replace("/\{EDIT_USER_NEW_PASSWORD_2\}/", $save_pw, $page_edit_user_adduser);
 
@@ -489,15 +503,16 @@
 						}
 					elseif($users[$i]['user_level'] == 0)
 						{
-						$edit_user_icon_adduser = "<a href=\"admin.php?action=editusers&amp;mode=adduser".$sid."\"><img class=\"icon\" src=\"../images/".$settings['iconset_path']."/user_adduser.png\" title=\"".$lang['user_add']."\" alt=\"".$lang['user_add']."\"></a>";							
+						$edit_user_icon_adduser = "<a href=\"admin.php?action=editusers&amp;mode=adduser".$sid."\"><img class=\"icon\" src=\"templates/default/images/user_adduser.png\" title=\"".$lang['user_add']."\" alt=\"".$lang['user_add']."\"></a>";
 						}
 
 					// fill template with entry (strings)
 					$page_edit_user[$i] = preg_replace("/\{EDIT_USER_ID\}/", $users[$i]['ID'], $page_edit_user[$i]);
 					$page_edit_user[$i] = preg_replace("/\{EDIT_USER_NAME\}/", $users[$i]['user_name'], $page_edit_user[$i]);
-					$page_edit_user[$i] = preg_replace("/\{EDIT_USER_ICON_EDIT\}/", "<a href=\"admin.php?action=editusers&amp;mode=edit&amp;id=".$users[$i]['ID'].$sid."\"><img class=\"icon\" src=\"../images/".$settings['iconset_path']."/user_edit.png\" title=\"".$lang['user_edit']."\" alt=\"".$lang['user_edit']."\"></a>", $page_edit_user[$i]);
+					if($users[$i]['user_level'] == 0) { $user_level = $lang['administrator']; } else { $user_level = $lang['moderator']; }
+					$page_edit_user[$i] = preg_replace("/\{EDIT_USER_LEVEL\}/", $user_level, $page_edit_user[$i]);
+					$page_edit_user[$i] = preg_replace("/\{EDIT_USER_ICON_EDIT\}/", "<a href=\"admin.php?action=editusers&amp;mode=edit&amp;id=".$users[$i]['ID'].$sid."\"><img class=\"icon\" src=\"templates/default/images/user_edit.png\" title=\"".$lang['user_edit']."\" alt=\"".$lang['user_edit']."\"></a>", $page_edit_user[$i]);
 					$page_edit_user[$i] = preg_replace("/\{EDIT_USER_ICON_ADDUSER\}/", $edit_user_icon_adduser, $page_edit_user[$i]);
-					$page_edit_user[$i] = preg_replace("/\{TEMPLATE_PATH\}/", "templates/".$settings['template_path'], $page_edit_user[$i]);
 
 					if(!isset($page_include)) { $page_include = NULL; }
 					$page_include .= $page_edit_user[$i];
