@@ -291,18 +291,19 @@
 
 			$timestamp = $date."&nbsp;".$lang['at']."&nbsp;".$time."&nbsp;".$lang['oclock'];
 
-			if ($settings['gravatar_show'] == 1)
+		if ($settings['gravatar_show'] == 1)
 				{
 				// load gravatar
 				if($settings['gravatar_rating'] == 0) { $gravatar_rating = "G"; }
 				if($settings['gravatar_rating'] == 1) { $gravatar_rating = "PG"; }
 				if($settings['gravatar_rating'] == 2) { $gravatar_rating = "R"; }
 				if($settings['gravatar_rating'] == 3) { $gravatar_rating = "X"; }
-				$gravatar_url = "http://www.gravatar.com/avatar.php?gravatar_id=".md5($entry[$i]['email'])."&amp;size=40&amp;rating=".$gravatar_rating;
-				$gravatar_size = 40;
-				$img_gravatar = "<img src=\"".$gravatar_url."\" width=\"".$gravatar_size."\" height=\"".$gravatar_size."\" class=\"gravatar\" alt=\"".$lang['gravatar']."\" title=\"".$lang['gravatar']."\">";
+
+				$gravatar_size = 50;
+				$gravatar_url = "http://www.gravatar.com/avatar/".md5( strtolower( trim($entry[$i]['email'])))."?s=".$gravatar_size."&amp;r=".$gravatar_rating."&amp;d=wavatar";
+				$img_gravatar = "<img src=\"".$gravatar_url."\" class=\"gravatar\" style=\" width: ".$gravatar_size."px; height: ".$gravatar_size."px;\" alt=\"".$lang['gravatar']."\" title=\"".$lang['gravatar']."\">";
 				}
-			else
+			 else
 				{
 				$gravatar_size = 0;
 				$img_gravatar = NULL;
