@@ -80,7 +80,9 @@
 	$lang['errormessage7'] = "De captcha-code was niet goed ingetypt!";
 	$lang['errormessage8'] = "Deze gebruiker ontvangt geen e-mail";
 	$lang['errormessage9'] = "Er was een fout bij het versturen van de mail!";
-	$lang['security_code'] = "Beveiligings-code (captcha)";	
+	$lang['errormessage10'] = "Spamprotection: The formular was sent too fast. Please wait {TIME_LOCK_REST} more seconds. Thank you.";
+	$lang['errormessage11'] = "The Akismet data privacy agreement was not accepted. It MUST be accepted to save the entry.";
+	$lang['security_code'] = "Beveiligings-code (captcha)";
 	$lang['captcha_what_is_that'] = "Wat is dit?";
 	$lang['captcha_wikipedia'] = "http://en.wikipedia.org/wiki/Captcha";
 	$lang['captcha_tooltip'] = "Een nieuwe gastenboek entry vereist het invoeren van de captcha-code, dit om geautomatiseerd invoeren te voorkomen. Typ enkel HOOFDLETTERS. Als de code onleesbaar is, laat dan het veld leeg en klik op ''Verzenden''. Er zal een nieuwe captcha gegenereerd worden. Je andere velden blijven dan ingevuld. Als er geen nieuwe captcha gegenereerd wordt klik dan op ''vernieuwen'' of typ [CTRL]+[R].";
