@@ -55,7 +55,7 @@
 	$lang['errormessage7'] = "Die angegebene eMail Adresse ist nicht g&uuml;ltig, oder es wurde keine angegeben.";
 	$lang['errormessage8'] = "Du kannst Dir nicht selbst den Administratorstatus nehmen, Dein eigenes Benutzerkonto deaktivieren, oder es l&ouml;schen.";
 	$lang['errormessage9'] = "Du warst zu lange inaktiv, und wurdest deshalb automatisch abgemeldet.";
-	$lang['errormessage10'] = "Beim letzten Besuch hast Du vergessen Dich auszuloggen. Du wurdest deshalb automatisch abgemeldet.<br><br>Bitte benutze zu Deiner eigenen Sicherheit immer den Knopf ''Abmelden'' um Dich auszuloggen. Danke.";
+	$lang['errormessage10'] = "Beim letzten Besuch hast Du vergessen Dich abzumelden. Dies wurde automatisch erledigt.<br><br>Bitte benutze zu Deiner eigenen Sicherheit immer den Knopf ''Abmelden'', wenn Du die Administration verl&auml;sst. Danke.";
 	$lang['errormessage11'] = "Dieser Benutzername oder diese eMail Adresse wird bereits verwendet.";
 	$lang['errormessage12'] = "Dieser Schl&uuml;ssel ist ung&uuml;ltig oder bereits abgelaufen.";
 	$lang['errormessage13'] = "Es wurde bereits ein neues Passwort f&uuml;r dieses Benutzerkonto beantragt.<br>Es ist nicht m&ouml;glich ein weiteres Passwort zu beantragen, bis das Neue aktiviert, oder abgelaufen ist.";
@@ -166,6 +166,9 @@
 	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
 	$lang['edit_akismet_api'] = "Akismet API Key (erforderlich):";
 	$lang['edit_akismet_mark_as_spam'] = "Spam-Markierung:";
+	$lang['edit_time_lock'] = "Absendesperre:";
+	$lang['edit_time_lock_value'] = "Minimale Zeit f&uuml;r Absendesperre:";
+	$lang['edit_time_lock_maxtime'] = "Maximale Zeit f&uuml;r Absendesperre:";
 	$lang['edit_user_notification'] = "Benutzerbenachrichtigung:";
 	$lang['edit_user_show_email'] = "Benutzeremail im G&auml;stebuch:";
 	$lang['edit_session_timeout'] = "Ablaufzeit der Session:";
@@ -204,11 +207,14 @@
 	$lang['edit_expl_smileys'] = "Erm&ouml;glicht es dem Benutzer Smilies einzuf&uuml;gen.";
 	$lang['edit_expl_captcha'] = "Bei Aktivierung muss ein Sicherheitscode eingegeben werden, um einen neuen Eintrag und eine eMail an einen Benutzer zu schreiben.";
 	$lang['edit_expl_captcha_method'] = "Du kannst zwischen einem Sicherheitscode und einem mathematischen Captcha, bei dem der Benutzer eine Rechenaufgabe l&ouml;sen muss, w&auml;hlen.";
-	$lang['edit_expl_akismet_plugin'] = "Akismet ist ein externer Service, der neue Eintr&auml;ge auf Spam pr&uuml;ft, und bei einem positiven Ergebnis den Eintrag blockt. Das Akismet-Plugin kann auf <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a> herunter geladen werden.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet ist ein externer Service, der neue Eintr&auml;ge auf Spam pr&uuml;ft, und bei einem positiven Ergebnis den Eintrag blockt. Das Akismet-Plugin kann auf <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a> herunter geladen werden.<br><br><b>ACHTUNG: Mit der Nutzung von 'Akismet' erklärst Du Dich einverstanden, dass Daten auf einen Server in die USA übermittelt werden. Bist Du damit nicht einverstanden, darfst Du das Plugin nicht benutzen! Ebenso müssen Benutzer, die Einträge verfassen, der Übermittlung der Daten in die USA zustimmen.</b>";
 	$lang['edit_expl_akismet_api'] = "Um Akismet nutzen zu k&ouml;nnen, ist das Akismet-Plugin sowie ein <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a> erforderlich. Gib ihn nach der Registrierung hier ein.";
 	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet ist installiert!</span>";
 	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet ist NICHT installiert!</span>";
 	$lang['edit_expl_akismet_mark_as_spam'] = "Ist diese Option aktiv, werden neue, von Akismet als Spam identifizierte Eintr&auml;ge, als solcher markiert, und erscheinen in der Administration in der Kategorie Spam.";
+	$lang['edit_expl_time_lock'] = "Wenn diese Option aktiviert wird, l&auml;uft bei einem neuen G&auml;stebucheintrag im Hintergrund ein Z&auml;hler mit. Sendet der Benutzer das Formular vor Ablauf dieses Z&auml;hlers ab, wird er darauf hingewiesen dass er zu schnell war, und wie viele Sekunden er noch warten muss, um das Formular abzusenden.";
+	$lang['edit_expl_time_lock_value'] = "Die minimale Zeit in Sekunden die der Benutzer warten muss, bis er das Formular absenden kann.";
+	$lang['edit_expl_time_lock_maxtime'] = "Die maximale Zeit in Sekunden in der ein Benutzer Gelegenheit hat, einen G&auml;stebucheintrag zu hinterlassen. L&auml;uft die Zeit w&auml;hrend des G&auml;stebucheintrags ab, beginnt die Absendesperre von vorne.";
 	$lang['edit_expl_user_notification'] = "Erm&ouml;glicht es dem Benutzer zu entscheiden, ob er sich per eMail benachrichtigen lassen will wenn sein Eintrag freigeschaltet wurde.";
 	$lang['edit_expl_user_show_email'] = "Erm&ouml;glicht es dem Benutzer zu entscheiden, ob seine eMail im G&auml;stebuch angezeigt wird, oder nicht. Deaktiviert er das K&auml;stchen kann ihm niemand au&szlig;er der Administrator eine eMail schreiben.";
 	$lang['edit_expl_session_timeout'] = "Ein Benutzer wird bei Inaktivit&auml;t nach Ablauf dieser Zeit automatisch abgemeldet. Angabe in <b>Sekunden</b>. Wert muss >= <b>60</b> sein.";
