@@ -207,7 +207,7 @@
 	$lang['edit_expl_smileys'] = "Erm&ouml;glicht es dem Benutzer Smilies einzuf&uuml;gen.";
 	$lang['edit_expl_captcha'] = "Bei Aktivierung muss ein Sicherheitscode eingegeben werden, um einen neuen Eintrag und eine eMail an einen Benutzer zu schreiben.";
 	$lang['edit_expl_captcha_method'] = "Sie k&ouml;nnen zwischen einem Sicherheitscode und einem mathematischen Captcha, bei dem der Benutzer eine Rechenaufgabe l&ouml;sen muss, w&auml;hlen.";
-	$lang['edit_expl_akismet_plugin'] = "Akismet ist ein externer Service, der neue Eintr&auml;ge auf Spam pr&uuml;ft, und bei einem positiven Ergebnis den Eintrag blockt. Das Akismet-Plugin kann auf <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a> herunter geladen werden.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet ist ein externer Service, der neue Eintr&auml;ge auf Spam pr&uuml;ft, und bei einem positiven Ergebnis den Eintrag blockt. Das Akismet-Plugin kann auf <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a> herunter geladen werden.<br><br><b>ACHTUNG: Mit der Nutzung von 'Akismet' erklärst Du Dich einverstanden, dass Daten auf einen Server in die USA übermittelt werden. Bist Du damit nicht einverstanden, darfst Du das Plugin nicht benutzen! Ebenso müssen Benutzer, die Einträge verfassen, der Übermittlung der Daten in die USA zustimmen.</b>";
 	$lang['edit_expl_akismet_api'] = "Um Akismet nutzen zu k&ouml;nnen, ist das Akismet-Plugin sowie ein <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a> erforderlich. Geben Sie ihn nach der Registrierung hier ein.";
 	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet ist installiert!</span>";
 	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet ist NICHT installiert!</span>";
