@@ -106,9 +106,10 @@
 		$_POST['hp'] = cleanstr($_POST['hp']);
 		$_POST['user_notification'] = cleanstr($_POST['user_notification']);
 		$_POST['user_show_email'] = cleanstr($_POST['user_show_email']);
+		$_POST['user_accept_akismet_service'] = cleanstr($_POST['user_accept_akismet_service']);
 
 		// include akismet if it exists
-		if (file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_api'])) AND ($settings['akismet_api'] != "") AND ($_POST['name'] != "") AND ($_POST['email'] != "") AND ($_POST['message'] != ""))
+		if (file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_api'])) AND ($settings['akismet_api'] != "") AND (isset($_POST['user_accept_akismet_service']) AND $_POST['user_accept_akismet_service'] == 1) AND ($_POST['name'] != "") AND ($_POST['email'] != "") AND ($_POST['message'] != ""))
 			{
 			include ("plugins/akismet/akismet.class.php");
 
@@ -272,6 +273,7 @@
 		// if you want the email field to be not necessary, just outcomment next line with "//"
 		if (!$_POST['email']) { $errorcode = 2; }
 		if (!$_POST['name']) { $errorcode = 3; }
+		if ((isset($settings['akismet_plugin'])) AND ($settings['akismet_plugin'] == 1) AND $_POST['user_accept_akismet_service'] != 1) { $errorcode = 11; }
 		
 		// uncomment this to block ip-adresses
 		//if ($_SERVER["REMOTE_ADDR"] == "XXx.xxx.xxx.xxx") { die(); }
@@ -416,6 +418,7 @@
 			if ($errorcode == 5) { $errormessage = $_POST['icq']."&nbsp;".$lang['errormessage5']; }
 			if ($errorcode == 7) { $errormessage = $lang['errormessage7']; }
 			if ($errorcode == 10) { $errormessage = $lang['errormessage10']; }
+			if ($errorcode == 11) { $errormessage = $lang['errormessage11']; }
 
 			// do not refresh site
 			$refresh = "";
@@ -622,6 +625,17 @@
 		$user_show_email = NULL;
 		}
 
+	// insert template if akismet is acitvated
+	if (file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_plugin'])) AND ($settings['akismet_plugin'] == 1))
+		{
+		$content_newentry_user_accept_akismet_service = preg_replace("/\{LANG_USER_ACCEPT_AKISMET_SERVICE\}/", $lang['user_accept_akismet_service'], $content_newentry_user_accept_akismet_service);
+		$user_accept_akismet_service = $content_newentry_user_accept_akismet_service;
+		}
+	else
+		{
+		$user_accept_akismet_service = NULL;
+		}
+
 	// fill template with captcha
 	if(($settings['captcha'] == 1) AND ($captcha_generated != 1))
 		{
@@ -652,6 +666,7 @@
 		$page_newentry_body = preg_replace("/\{TEMPLATE_BBCODES\}/", $bbcodes, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_USER_NOTIFICATION\}/", $user_notification, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_USER_SHOW_EMAIL\}/", $user_show_email, $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{TEMPLATE_USER_ACCEPT_AKISMET_SERVICE\}/", $user_accept_akismet_service, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_CAPTCHA\}/", $captcha_img, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_COPYRIGHT\}/", $content_copyright, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_FOOTER\}/", $page_footer, $page_newentry_body);
