@@ -113,6 +113,14 @@
 
 	if(isset($update_necessary) AND $update_necessary == 1)
 		{
+		if($settings['version'] == "0.6.7")
+			{
+			include "upgrade/067.php";
+			}
+		if($settings['version'] == "0.6.6")
+			{
+			include "upgrade/066.php";
+			}
 		if($settings['version'] == "0.6.5")
 			{
 			include "upgrade/065.php";
