@@ -157,9 +157,12 @@ $sqldescription[7] = "- Inserting field for akismet spam-marking (settings)...";
 $sql[8] = "ALTER TABLE `".$db['prefix']."user` ADD `r_spam` TINYINT( 1 ) NOT NULL AFTER `r_edit` ;";
 $sqldescription[8] = "- Inserting field for new user right 'manage spam'...";
 
-// update version number every time
-$sql[9] = "UPDATE `".$db['prefix']."settings` SET `version` = '".MGB_VERSION."'";
-$sqldescription[9] = "- Updating version number...";
+$sql[9] = "ALTER TABLE `".$db['prefix']."settings` ADD `time_lock` INT( 1 ) NOT NULL AFTER `akismet_mark_as_spam` , ADD `time_lock_value` INT( 3 ) DEFAULT '30' NOT NULL AFTER `time_lock` , ADD `time_lock_maxtime` INT DEFAULT '300' NOT NULL AFTER `time_lock_value` ";
+$sqldescription[9] = "- Inserting fields for time lock (settings)...";
 
-$to = 9;
+// update version number every time
+$sql[10] = "UPDATE `".$db['prefix']."settings` SET `version` = '".MGB_VERSION."'";
+$sqldescription[10] = "- Updating version number...";
+
+$to = 10;
 ?>
